==> nextcloud-29.0.5.tgz: nextcloud/apps/photos/l10n/es_AR.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "Videos" : "Videos",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Photos settings" : "Configuración de fotos",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "Shared by" : "Compartido por",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "Group" : "Grupo",
    "Copy public link" : "Copiar link publico",
    "An error occurred" : "Ocurrió un error",
    "Favorite" : "Favorito",
    "Open the full size \"{name}\" image" : "Abrir imagen a tamaño completo \"{nombre}\"",
    "Go back" : "Regresar",
    "Back to {folder}" : "Volver a {carpeta}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Home" : "Casa",
    "View" : "Ver",
    "Remove from favorites" : "Eliminado de favoritos",
    "This folder does not exist" : "Esta carpeta no existe",
    "No photos in here" : "No hay fotos aquí",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Add" : "Añadir",
    "Tagged photos" : "Fotos etiquetadas",
    "Details" : "Detalles"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/photos/l10n/es_AR.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "Videos" : "Videos",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Photos settings" : "Configuración de fotos",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "Shared by" : "Compartido por",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "Group" : "Grupo",
    "Copy public link" : "Copiar link publico",
    "An error occurred" : "Ocurrió un error",
    "Favorite" : "Favorito",
    "Open the full size \"{name}\" image" : "Abrir imagen a tamaño completo \"{nombre}\"",
    "Go back" : "Regresar",
    "Back to {folder}" : "Volver a {carpeta}",
    "Share this folder" : "Compartir esta carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Home" : "Casa",
    "View" : "Ver",
    "Remove from favorites" : "Eliminado de favoritos",
    "This folder does not exist" : "Esta carpeta no existe",
    "No photos in here" : "No hay fotos aquí",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Tagged photos" : "Fotos etiquetadas",
    "Details" : "Detalles",
    "Add" : "Añadir"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
